@@ -25,6 +25,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#ifdef HAVE_SIGNAL_H
+#include <signal.h>
+#endif
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
